from dolfin import *

# Create mesh and define function space
Th = UnitSquareMesh(20,20)
Vh = FunctionSpace(Th, "CG", 1)

# Define constants
mu = Constant(0.01)
rho = Constant(1.0)

# Define boundary conditions
def Boundary(x, on_boundary):
	return on_boundary
bc = DirichletBC(Vh, Constant("0.0"), Boundary)

# Define variational problem
du = TrialFunction(Vh)
v  = TestFunction(Vh)
u = Function(Vh)
F  = (mu*inner(grad(u), grad(v))+rho*(u*u*v)-v)*dx
J = derivative(F, u, du)

# Compute solution
problem = NonlinearVariationalProblem(F, u, bc, J)
solver  = NonlinearVariationalSolver(problem)
solver.solve()

# Plot solution and mesh
plot(u)
plot(Th)

# Hold plot
interactive()
